==> driza-0.6.3.tar.gz: driza-0.6.3/Driza/dialogs/dimportartexto.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#Copyright (C) 2006 Néstor Arocha Rodríguez, Inmaculada Luengo Merino

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""Dialogo de importacion de texto"""

from Driza.ui.dialogos.dimportartexto import DialogoImportarTexto
from qt import *


class DImportarTexto(DialogoImportarTexto):
    """
    Dialogo de creación de variables, 
    permite obtener nuevas variables a partir de las ya existentes
    """

    def __init__(self, parent, gestorficheros):
        """Inicialización"""
        DialogoImportarTexto.__init__(self, parent, "dialogo importar texto", \
                0, 0)
        self.setFinishEnabled(self.page(1), True)
        self.setNextEnabled(self.page(0), False)
        self.setHelpEnabled(self.page(0), False)
        self.setHelpEnabled(self.page(1), False)
        self.archivo = None
        self.__gestorfichero = gestorficheros
        self.__conexiones()
    #FUNCIONES PUBLICAS        

    def accept(self):
        """Aceptacion del dialogo"""
        if self.comboBox1.currentText() == "Espacio":
            delatr = ""
        elif self.comboBox1.currentText() == "Dos puntos":
            delatr = ":"
        else:
            delatr = "\t"
        if self.checkBox1.isChecked():
            cabecera = True
        else:
            cabecera = False
        try:
            self.__gestorfichero.importartexto(self.archivo, \
                    delimitadoratrib = delatr, cabeceras = cabecera)
        except:
            print "Error en la importacion (TODO)"
        DialogoImportarTexto.accept(self)
        self.parent().grid.myUpdate()


    #FUNCIONES PRIVADAS
    def __conexiones(self):
        """Bloque de conexiones"""
        self.connect(self.pushButton1, SIGNAL("clicked()"), \
                self.__seleccionarfichero)

    def __seleccionarfichero(self):
        """
        Detemina que hacer cuando se pulsa 
        el boton de seleccion de fichero
        """
        filtro = "%s files (*.%s);;" % ("Txt", "txt")
        cadenaarchivo = str(QFileDialog.getOpenFileName(QString.null, filtro, \
                self, None, "importar fichero", ""))
        self.archivo = cadenaarchivo
        self.textLabel1.setText(cadenaarchivo)
        self.setNextEnabled(self.page(0), True)

==> driza-0.6.4.tar.gz: driza-0.6.4/Driza/dialogs/dimportartexto.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#Copyright (C) 2006 Néstor Arocha Rodríguez, Inmaculada Luengo Merino

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""Dialogo de importacion de texto"""

from Driza.ui.dialogos.dimportartexto import DialogoImportarTexto
from qt import *


class DImportarTexto(DialogoImportarTexto):
    """
    Dialogo de creación de variables, 
    permite obtener nuevas variables a partir de las ya existentes
    """

    def __init__(self, parent, interfazdatosfichero):
        """Inicialización"""
        DialogoImportarTexto.__init__(self, parent, "dialogo importar texto", \
                0, 0)
        self.setFinishEnabled(self.page(1), True)
        self.setNextEnabled(self.page(0), False)
        self.setHelpEnabled(self.page(0), False)
        self.setHelpEnabled(self.page(1), False)
        self.archivo = None
        self.__idf = interfazdatosfichero
        self.__conexiones()
    #FUNCIONES PUBLICAS        

    def accept(self):
        """Aceptacion del dialogo"""
        if self.comboBox1.currentText() == "Espacio":
            delatr = ""
        elif self.comboBox1.currentText() == "Dos puntos":
            delatr = ":"
        else:
            delatr = "\t"
        if self.checkBox1.isChecked():
            cabecera = True
        else:
            cabecera = False
        try:
            self.__idf.borrartodo()
            self.__idf.loadTxt(self.archivo, delimitadoratrib = delatr, cabeceras = cabecera)
        except:
            msg = u"Error desconocido en la importación"
            QMessageBox.critical(self,u'Error!', msg)
        DialogoImportarTexto.accept(self)
        self.parent().grid.myUpdate()


    #FUNCIONES PRIVADAS
    def __conexiones(self):
        """Bloque de conexiones"""
        self.connect(self.pushButton1, SIGNAL("clicked()"), \
                self.__seleccionarfichero)

    def __seleccionarfichero(self):
        """
        Detemina que hacer cuando se pulsa 
        el boton de seleccion de fichero
        """
        filtro = "%s files (*.%s);;" % ("Txt", "txt")
        cadenaarchivo = str(QFileDialog.getOpenFileName(QString.null, filtro, \
                self, None, "importar fichero", ""))
        if cadenaarchivo:
            self.archivo = cadenaarchivo
            self.textLabel1.setText(cadenaarchivo)
            self.setNextEnabled(self.page(0), True)
